rayoptics.optical package
=========================

Submodules
----------

rayoptics.optical.elements module
---------------------------------

.. automodule:: rayoptics.optical.elements
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.firstorder module
-----------------------------------

.. automodule:: rayoptics.optical.firstorder
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.gap module
----------------------------

.. automodule:: rayoptics.optical.gap
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.medium module
-------------------------------

.. automodule:: rayoptics.optical.medium
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.model\_constants module
-----------------------------------------

.. automodule:: rayoptics.optical.model_constants
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.model\_enums module
-------------------------------------

.. automodule:: rayoptics.optical.model_enums
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.opticalmodel module
-------------------------------------

.. automodule:: rayoptics.optical.opticalmodel
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.opticalspec module
------------------------------------

.. automodule:: rayoptics.optical.opticalspec
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.paraxialdesign module
---------------------------------------

.. automodule:: rayoptics.optical.paraxialdesign
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.profiles module
---------------------------------

.. automodule:: rayoptics.optical.profiles
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.raytrace module
---------------------------------

.. automodule:: rayoptics.optical.raytrace
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.sequential module
-----------------------------------

.. automodule:: rayoptics.optical.sequential
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.specsheet module
----------------------------------

.. automodule:: rayoptics.optical.specsheet
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.surface module
--------------------------------

.. automodule:: rayoptics.optical.surface
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.thinlens module
---------------------------------

.. automodule:: rayoptics.optical.thinlens
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.thirdorder module
-----------------------------------

.. automodule:: rayoptics.optical.thirdorder
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.trace module
------------------------------

.. automodule:: rayoptics.optical.trace
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.traceerror module
-----------------------------------

.. automodule:: rayoptics.optical.traceerror
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.transform module
----------------------------------

.. automodule:: rayoptics.optical.transform
    :members:
    :undoc-members:
    :show-inheritance:

rayoptics.optical.twoconicmirrors module
----------------------------------------

.. automodule:: rayoptics.optical.twoconicmirrors
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: rayoptics.optical
    :members:
    :undoc-members:
    :show-inheritance:
